==> material-ui-shell-1.0.4.tgz: package/es/pages/PageNotFound/PageNotFound.js <==
var _this = this,
    _jsxFileName = "C:\\github\\os\\react-most-wanted\\packages\\material-ui-shell\\src\\pages\\PageNotFound\\PageNotFound.js";

import React from 'react';
import { injectIntl } from 'react-intl';
import Page from '../../containers/Page/Page';
import Button from '@material-ui/core/Button';
import Home from '@material-ui/icons/Home';
import Paper from '@material-ui/core/Paper';
import Typography from '@material-ui/core/Typography';
import { withStyles } from '@material-ui/core/styles';

var styles = function styles(theme) {
  return {
    icon: {
      width: 192,
      height: 192,
      color: theme.palette.secondary.main
    },
    container: {
      display: 'flex',
      flexDirection: 'column',
      alignItems: 'center',
      justifyContent: 'center',
      height: "100%"
    },
    paper: {
      backgroundColor: theme.palette.background.default,
      margin: 0,
      height: "calc(100vh - 64px)"
    },
    button: {
      marginTop: 20
    }
  };
};

var PageNotFound = function PageNotFound(_ref) {
  var intl = _ref.intl,
      classes = _ref.classes;
  return /*#__PURE__*/React.createElement(Page, {
    pageTitle: intl.formatMessage({
      id: 'page_not_found'
    }) + ' MUI',
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 35,
      columnNumber: 5
    }
  }, /*#__PURE__*/React.createElement(Paper, {
    className: classes.paper,
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 36,
      columnNumber: 7
    }
  }, /*#__PURE__*/React.createElement("div", {
    className: classes.container,
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 37,
      columnNumber: 9
    }
  }, /*#__PURE__*/React.createElement(Typography, {
    variant: "h4",
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 38,
      columnNumber: 11
    }
  }, "404"), /*#__PURE__*/React.createElement(Typography, {
    variant: "subtitle1",
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 41,
      columnNumber: 11
    }
  }, intl.formatMessage({
    id: 'page_not_found'
  }) + ' MUI'), /*#__PURE__*/React.createElement(Button, {
    color: "secondary",
    "aria-label": "home",
    href: "/",
    className: classes.button,
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 44,
      columnNumber: 11
    }
  }, /*#__PURE__*/React.createElement(Home, {
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 50,
      columnNumber: 13
    }
  })))));
};

export default injectIntl(withStyles(styles, {
  withTheme: true
})(PageNotFound));

==> material-ui-shell-1.0.8.tgz: package/es/pages/PageNotFound/PageNotFound.js <==
import React from 'react';
import { injectIntl } from 'react-intl';
import Page from '../../containers/Page/Page';
import Button from '@material-ui/core/Button';
import Home from '@material-ui/icons/Home';
import Paper from '@material-ui/core/Paper';
import Typography from '@material-ui/core/Typography';
import { withStyles } from '@material-ui/core/styles';

var styles = function styles(theme) {
  return {
    icon: {
      width: 192,
      height: 192,
      color: theme.palette.secondary.main
    },
    container: {
      display: 'flex',
      flexDirection: 'column',
      alignItems: 'center',
      justifyContent: 'center',
      height: "100%"
    },
    paper: {
      backgroundColor: theme.palette.background.default,
      margin: 0,
      height: "calc(100vh - 64px)"
    },
    button: {
      marginTop: 20
    }
  };
};

var PageNotFound = function PageNotFound(_ref) {
  var intl = _ref.intl,
      classes = _ref.classes;
  return /*#__PURE__*/React.createElement(Page, {
    pageTitle: intl.formatMessage({
      id: 'page_not_found'
    }) + ' MUI'
  }, /*#__PURE__*/React.createElement(Paper, {
    className: classes.paper
  }, /*#__PURE__*/React.createElement("div", {
    className: classes.container
  }, /*#__PURE__*/React.createElement(Typography, {
    variant: "h4"
  }, "404"), /*#__PURE__*/React.createElement(Typography, {
    variant: "subtitle1"
  }, intl.formatMessage({
    id: 'page_not_found'
  }) + ' MUI'), /*#__PURE__*/React.createElement(Button, {
    color: "secondary",
    "aria-label": "home",
    href: "/",
    className: classes.button
  }, /*#__PURE__*/React.createElement(Home, null)))));
};

export default injectIntl(withStyles(styles, {
  withTheme: true
})(PageNotFound));
